const path = require("path");
const webpack = require("webpack");
const ExtractTextPlugin = require("extract-text-webpack-plugin");
const StyleLintPlugin = require("stylelint-webpack-plugin");
const CheckerPlugin = require("awesome-typescript-loader").CheckerPlugin;
const bundleOutputDir = "./wwwroot/dist";
module.exports = env => {
  const isDevBuild = !(env && env.prod);
  return [
    {
      stats: {
        modules: false
      },
      entry: {
        main: "./src/.tsx"
      },
      resolve: {
        extensions: [".js", ".jsx", ".ts", ".tsx"]
        // alias: {
        //   "react-dom": "@hot-loader/react-dom"
        // }
      },
      output: {
        path: path.join(__dirname, bundleOutputDir),
        filename: "[name].js",
        publicPath: "/dist/"
      },
      module: {
        rules: [
          {
            test: /\.(sc|c)ss$/,
            use: isDevBuild
              ? [
                  {
                    loader: "style-loader",
                    options: {
                      sourceMap: true
                    }
                  },
                  {
                    loader: "css-loader",
                    options: {
                      sourceMap: true
                    }
                  },
                  {
                    loader: "postcss-loader",
                    options: {
                      plugins: () => [require("autoprefixer")]
                    }
                  }
                ]
              : ExtractTextPlugin.extract({
                  fallback: "style-loader",
                  use: [
                    {
                      loader: require.resolve("css-loader"),
                      options: {
                        minimize: true
                      }
                    },
                    {
                      loader: "postcss-loader",
                      options: {
                        plugins: () => [require("autoprefixer")]
                      }
                    }
                  ]
                })
          },
          {
            test: /\.tsx?$/,
            include: /ClientApp/,
            use: ["awesome-typescript-loader?silent=true"]
          },
          // { test: /\.css$/, use: isDevBuild ? ['style-loader', 'css-loader'] : ExtractTextPlugin.extract({ use: 'css-loader?minimize' }) },
          {
            test: /.(png|jpg|jpeg|gif|svg|woff|woff2|eot|ttf)(\?v=\d+\.\d+\.\d+)?$/,
            use: "url-loader?limit=25000"
          },
          {
            test: /\.jpe?g$|\.ico$|\.gif$|\.png$|\.svg$|\.wav$|\.mp3$/,
            use: "file-loader?name=[name].[ext]"
          } // <-- retain original file name
        ]
      },
      plugins: [
        new CheckerPlugin(),
        new webpack.DllReferencePlugin({
          context: __dirname,
          manifest: require("./wwwroot/dist/vendor-manifest.json")
        })
      ].concat(
        isDevBuild
          ? [
              new StyleLintPlugin({
                configFile: path.resolve(__dirname, "stylelint.config.js"),
                context: path.resolve(__dirname, "./ClientApp/"),
                files: "**/*.css",
                failOnError: false,
                quiet: false
              }),
              // Plugins that apply in development builds only
              new webpack.SourceMapDevToolPlugin({
                filename: "[file].map", // Remove this line if you prefer inline source maps
                moduleFilenameTemplate: path.relative(
                  bundleOutputDir,
                  "[resourcePath]"
                ) // Point sourcemap entries to the original file locations on disk
              })
            ]
          : [
              // Plugins that apply in production builds only
              new webpack.optimize.UglifyJsPlugin(),
              new ExtractTextPlugin("site.css")
            ]
      )
    }
  ];
};
